==> action-at-a-distance-1.0.11.tgz: package/app/scripts/controllers/spooky/spookyWiki.js <==
'use strict';

actionatadistanceApp.controller('SpookyWikiCtrl', function($scope, $rootScope) {
 
    var startUrl = 'http://en.wikipedia.org/wiki/Spooky_the_Tuff_Little_Ghost';
    var spookyActions = []; 

    spookyActions.push('ActionAtADistance.setSpookyResult(\n' +
        '\t{data: $("div#mw-content-text").html()}\n' +
        ');\n' +
        'console.log("Hello, from " + document.title);');


    var editor = CodeMirror.fromTextArea(document.getElementById("code"), {
        lineNumbers: true,
        matchBrackets: true,
        continueComments: "Enter",
        theme: "elegant"
      });

    if (typeof $rootScope.wikiActionAtADistance === 'undefined') {
        $rootScope.wikiActionAtADistance = ActionAtADistance();
    }

    var wikiActionAtADistance = $rootScope.wikiActionAtADistance;

    wikiActionAtADistance.init(function() {
        onConnect();
    });

    if (wikiActionAtADistance.connected()) {
        console.log('Page already loaded.');
        $scope.spookyAction = spookyActions[0];
        $scope.uuid = wikiActionAtADistance.uuid();
    }

    wikiActionAtADistance.onDocumentLoaded(function(documentLocationHref) {
        $scope.$apply(function () {
            $scope.spookyAction = spookyActions[0];
        });

        editor.setValue($scope.spookyAction);
    });

    wikiActionAtADistance.onEvaluateResponse(function(data) {
        $scope.$apply(function () {
            $scope.spooky = data.result;
        });
    });

    function onConnect() {
        wikiActionAtADistance.onConnect(function() {
            console.log('onConnect Wiki');
            wikiActionAtADistance.start(startUrl);
            $scope.uuid = wikiActionAtADistance.uuid();
        });
    }

    $scope.actionAtADistance = function() {
        wikiActionAtADistance.evaluate({action: $scope.spookyAction});
    };

    prettyPrint();

});

==> action-at-a-distance-1.0.19.tgz: package/app/scripts/controllers/spooky/spookyWiki.js <==
'use strict';

actionatadistanceApp.controller('SpookyWikiCtrl', function($scope, $rootScope) {
 
    var startUrl = 'http://en.wikipedia.org/wiki/Spooky_the_Tuff_Little_Ghost';
    var spookyActions = []; 

    spookyActions.push('ActionAtADistance.setSpookyResult(\n' +
        '\t{data: $("div#mw-content-text").html()}\n' +
        ');\n' +
        'console.log("Hello, from " + document.title);');


    var editor = CodeMirror.fromTextArea(document.getElementById("code"), {
        lineNumbers: true,
        matchBrackets: true,
        continueComments: "Enter",
        theme: "elegant"
      });

    if (typeof $rootScope.wikiActionAtADistance === 'undefined') {
        $rootScope.wikiActionAtADistance = ActionAtADistance();
    }

    var wikiActionAtADistance = $rootScope.wikiActionAtADistance;

    wikiActionAtADistance.connect(function() {
        wikiActionAtADistance.on('initResp', function onInit() {
            wikiActionAtADistance.start(startUrl);
            $scope.uuid = wikiActionAtADistance.uuid();
        });

        wikiActionAtADistance.on('callback', function (data) {
            if (data.action === 'documentLoaded') {
                $scope.$apply(function () {
                    $scope.spookyAction = spookyActions[0];
                });

                editor.setValue($scope.spookyAction);
            } else if (data.action === 'evaluate') {
                $scope.$apply(function () {
                    $scope.spooky = data.result;
                });
            }
        });

        wikiActionAtADistance.init();
    });

    if (wikiActionAtADistance.connected()) {
        $scope.uuid = wikiActionAtADistance.uuid();
    }

    $scope.actionAtADistance = function() {
        wikiActionAtADistance.evaluate({action: $scope.spookyAction});
    };

    prettyPrint();

});
